Documentation
¶
Index ¶
- Variables
- func KVStoreKeys() []string
- type AppKeepers
- func (appKeepers *AppKeepers) GenerateKeys()
- func (appKeepers *AppKeepers) GetKVStoreKey() map[string]*sdk.KVStoreKey
- func (appKeepers *AppKeepers) GetKey(storeKey string) *sdk.KVStoreKey
- func (appKeepers *AppKeepers) GetMemKey(storeKey string) *sdk.MemoryStoreKey
- func (appKeepers *AppKeepers) GetMemoryStoreKey() map[string]*sdk.MemoryStoreKey
- func (appKeepers *AppKeepers) GetSubspace(moduleName string) paramstypes.Subspace
- func (appKeepers *AppKeepers) GetTKey(storeKey string) *sdk.TransientStoreKey
- func (appKeepers *AppKeepers) GetTransientStoreKey() map[string]*sdk.TransientStoreKey
- func (appKeepers *AppKeepers) InitNormalKeepers(appCodec codec.Codec, bApp *baseapp.BaseApp, maccPerms map[string][]string, ...)
- func (appKeepers *AppKeepers) InitSpecialKeepers(appCodec codec.Codec, bApp *baseapp.BaseApp, wasmDir string, ...)
- func (appKeepers *AppKeepers) SetupHooks()
Constants ¶
This section is empty.
Variables ¶
var AppModuleBasics = []module.AppModuleBasic{ auth.AppModuleBasic{}, genutil.AppModuleBasic{}, bank.AppModuleBasic{}, capability.AppModuleBasic{}, staking.AppModuleBasic{}, mint.AppModuleBasic{}, distr.AppModuleBasic{}, gov.NewAppModuleBasic( append( wasmclient.ProposalHandlers, paramsclient.ProposalHandler, distrclient.ProposalHandler, upgradeclient.ProposalHandler, upgradeclient.CancelProposalHandler, poolincentivesclient.UpdatePoolIncentivesHandler, ibcclientclient.UpdateClientProposalHandler, ibcclientclient.UpgradeProposalHandler, superfluidclient.SetSuperfluidAssetsProposalHandler, superfluidclient.RemoveSuperfluidAssetsProposalHandler, )..., ), params.AppModuleBasic{}, crisis.AppModuleBasic{}, slashing.AppModuleBasic{}, authzmodule.AppModuleBasic{}, ibc.AppModuleBasic{}, upgrade.AppModuleBasic{}, evidence.AppModuleBasic{}, transfer.AppModuleBasic{}, vesting.AppModuleBasic{}, gamm.AppModuleBasic{}, txfees.AppModuleBasic{}, incentives.AppModuleBasic{}, lockup.AppModuleBasic{}, poolincentives.AppModuleBasic{}, epochs.AppModuleBasic{}, superfluid.AppModuleBasic{}, tokenfactory.AppModuleBasic{}, bech32ibc.AppModuleBasic{}, wasm.AppModuleBasic{}, }
AppModuleBasics returns ModuleBasics for the module BasicManager.
Functions ¶
func KVStoreKeys ¶
func KVStoreKeys() []string
TODO: We need to automate this, by bundling with a module struct...
Types ¶
type AppKeepers ¶
type AppKeepers struct {
// keepers, by order of initialization
// "Special" keepers
ParamsKeeper *paramskeeper.Keeper
CapabilityKeeper *capabilitykeeper.Keeper
CrisisKeeper *crisiskeeper.Keeper
UpgradeKeeper *upgradekeeper.Keeper
// make scoped keepers public for test purposes
ScopedIBCKeeper capabilitykeeper.ScopedKeeper
ScopedICAHostKeeper capabilitykeeper.ScopedKeeper
ScopedTransferKeeper capabilitykeeper.ScopedKeeper
ScopedWasmKeeper capabilitykeeper.ScopedKeeper
// "Normal" keepers
AccountKeeper *authkeeper.AccountKeeper
BankKeeper *bankkeeper.BaseKeeper
AuthzKeeper *authzkeeper.Keeper
StakingKeeper *stakingkeeper.Keeper
DistrKeeper *distrkeeper.Keeper
SlashingKeeper *slashingkeeper.Keeper
IBCKeeper *ibckeeper.Keeper
ICAHostKeeper *icahostkeeper.Keeper
TransferKeeper *ibctransferkeeper.Keeper
Bech32IBCKeeper *bech32ibckeeper.Keeper
Bech32ICS20Keeper *bech32ics20keeper.Keeper
EvidenceKeeper *evidencekeeper.Keeper
GAMMKeeper *gammkeeper.Keeper
LockupKeeper *lockupkeeper.Keeper
EpochsKeeper *epochskeeper.Keeper
IncentivesKeeper *incentiveskeeper.Keeper
MintKeeper *mintkeeper.Keeper
PoolIncentivesKeeper *poolincentiveskeeper.Keeper
TxFeesKeeper *txfeeskeeper.Keeper
SuperfluidKeeper *superfluidkeeper.Keeper
GovKeeper *govkeeper.Keeper
WasmKeeper *wasm.Keeper
TokenFactoryKeeper *tokenfactorykeeper.Keeper
// IBC modules
// transfer module
TransferModule transfer.AppModule
// contains filtered or unexported fields
}
func (*AppKeepers) GenerateKeys ¶
func (appKeepers *AppKeepers) GenerateKeys()
func (*AppKeepers) GetKVStoreKey ¶
func (appKeepers *AppKeepers) GetKVStoreKey() map[string]*sdk.KVStoreKey
func (*AppKeepers) GetKey ¶
func (appKeepers *AppKeepers) GetKey(storeKey string) *sdk.KVStoreKey
GetKey returns the KVStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*AppKeepers) GetMemKey ¶
func (appKeepers *AppKeepers) GetMemKey(storeKey string) *sdk.MemoryStoreKey
GetMemKey returns the MemStoreKey for the provided mem key.
NOTE: This is solely used for testing purposes.
func (*AppKeepers) GetMemoryStoreKey ¶
func (appKeepers *AppKeepers) GetMemoryStoreKey() map[string]*sdk.MemoryStoreKey
func (*AppKeepers) GetSubspace ¶
func (appKeepers *AppKeepers) GetSubspace(moduleName string) paramstypes.Subspace
func (*AppKeepers) GetTKey ¶
func (appKeepers *AppKeepers) GetTKey(storeKey string) *sdk.TransientStoreKey
GetTKey returns the TransientStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*AppKeepers) GetTransientStoreKey ¶
func (appKeepers *AppKeepers) GetTransientStoreKey() map[string]*sdk.TransientStoreKey
func (*AppKeepers) InitNormalKeepers ¶
func (*AppKeepers) InitSpecialKeepers ¶
func (*AppKeepers) SetupHooks ¶
func (appKeepers *AppKeepers) SetupHooks()
Click to show internal directories.
Click to hide internal directories.